local Dialog = require "engine.ui.Dialog"
local KeyBind = require "engine.KeyBind"
local SquelchOptions = require "engine.dialogs.SquelchOptions"

function squelchFilter(o)
  squelch = game.player.squelch
  if squelch == nil then
    return true
  elseif squelch.preserve_uniques and o.unique ~= nil then
    return true
  elseif squelch.preserve_infusions and o.subtype == "infusion" then
    return true
  elseif squelch.preserve_runes and o.subtype == "rune" then
    return true
  elseif squelch.onehanders and (o.subtype == "longsword" or o.subtype == "mace" or o.subtype == "waraxe") then
    return false
  elseif squelch.twohanders and (o.subtype == "battleaxe" or o.subtype == "greatmaul" or o.subtype == "greatsword") then
    return false
  elseif squelch.daggers and o.subtype == "dagger" then
    return false
  elseif squelch.staves and o.subtype == "staff" then
    return false
  elseif squelch.mindstars and o.subtype == "mindstar" then
    return false
  elseif squelch.whips and o.subtype == "whip" then
    return false
  elseif squelch.tridents and o.subtype == "trident" then
    return false
  elseif squelch.bows and (o.subtype == "longbow" or o.subtype == "arrow") then
    return false
  elseif squelch.slings and o.subtype == "sling" then
    return false
  elseif squelch.saws and o.subtype == "steamsaw" then
    return false
  elseif squelch.guns and o.subtype == "steamgun" then
    return false
  elseif (squelch.slings and squelch.guns) and o.subtype == "shot" then
    return false
  elseif squelch.tinkers and o.subtype == "steamtech" then
    return false
  elseif squelch.robes and o.subtype == "cloth" then
    return false
  elseif squelch.light and o.subtype == "light" then
    return false
  elseif squelch.heavy and o.subtype == "heavy" then
    return false
  elseif squelch.massive and o.subtype == "massive" then
    return false
  elseif squelch.shields and o.subtype == "shield" then
    return false
  elseif squelch.hats and o.subtype == "head" and not o.metallic then
    return false
  elseif squelch.helms and o.subtype == "head" and o.metallic then
    return false
  elseif squelch.cloaks and o.subtype == "cloak" then
    return false
  elseif squelch.gloves and o.subtype == "hands" and not o.metallic then
    return false
  elseif squelch.gauntlets and o.subtype == "hands" and o.metallic then
    return false
  elseif squelch.belts and o.subtype == "belt" then
    return false
  elseif squelch.boots and o.subtype == "feet" and not o.metallic then
    return false
  elseif squelch.sabatons and o.subtype == "feet" and o.metallic then
    return false
  elseif squelch.lites and o.subtype == "lite" then
    return false
  elseif squelch.wands and o.subtype == "wand" then
    return false
  elseif squelch.torques and o.subtype == "torque" then
    return false
  elseif squelch.totems and o.subtype == "totem" then
    return false
  elseif squelch.diggers and o.subtype == "digger" then
    return false
  elseif squelch.amulets and o.subtype == "amulet" then
    return false
  elseif squelch.rings and o.subtype == "ring" then
    return false
  elseif squelch.infusions and o.subtype == "infusion" then
    return false
  elseif squelch.runes and o.subtype == "rune" then
    return false
  elseif squelch.arcane and o.power_source ~= nil and o.power_source.arcane then
    return false
  elseif squelch.disrupting and o.power_source ~= nil and o.power_source.antimagic then
    return false
  elseif squelch.whiteinscriptions and not o.egoed and not o.unique and (o.subtype == "infusion" or o.subtype == "rune") then
    return false
  elseif squelch.whitejewelry and not o.egoed and not o.unique and (o.subtype == "ring" or o.subtype == "amulet") then
    return false
  elseif squelch.whiteequip and not o.egoed and not o.rare and not o.unique and o.subtype ~= "infusion" and o.subtype ~= "rune" and o.subtype ~= "ring" and o.subtype ~= "amulet" then
    return false
  elseif squelch.tier1 and o.material_level == 1 then
    return false
  elseif squelch.tier2 and o.material_level == 2 then
    return false
  elseif squelch.tier3 and o.material_level == 3 then
    return false
  elseif squelch.tier4 and o.material_level == 4 then
    return false
  elseif squelch.gego0 and (o.greater_ego == nil or o.greater_ego == 0) then
    return false
  elseif squelch.gego1 and o.greater_ego == 1 then
    return false
  end
  return true
end

class:bindHook("ToME:run", function(self, data)
  KeyBind:load("squelch")
  game.key:addBinds {
    SQUELCH = function()
      game:registerDialog(SquelchOptions.new(), 0) 
    end,
  }
end)

class:bindHook("Inventory:makeTabs", function(self, data)
  if data.tabslist[#data.tabslist] == nil then return end

  if data.tabslist[#data.tabslist].kind == "transmo" then
    data.tabslist[#data.tabslist].filter = function(o)
      return o.__transmo and squelchFilter(o)
    end
  end

  if data.tabslist[#data.tabslist].kind == "all" then
    data.tabslist[#data.tabslist+1] = {
      image="squelch.png", kind="squelch", desc="Squelched Items",
      filter=function(o) return o.__transmo and not squelchFilter(o) end
    }
  end
end)
